# django-calaccess-raw-data

A Django app to download, extract and load campaign finance and lobbying activity data from the California Secretary of State's [CAL-ACCESS](http://www.sos.ca.gov/prd/cal-access/) database

[![Build Status](https://travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data.png?branch=master)](https://travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data)
[![PyPI version](https://badge.fury.io/py/django-calaccess-raw-data.png)](http://badge.fury.io/py/django-calaccess-raw-data)
[![Coverage Status](https://coveralls.io/repos/california-civic-data-coalition/django-calaccess-raw-data/badge.png?branch=master)](https://coveralls.io/r/california-civic-data-coalition/django-calaccess-raw-data?branch=master)
[![Documentation Status](https://readthedocs.org/projects/django-calaccess-raw-data/badge/?version=latest)](https://django-calaccess-raw-data.readthedocs.org/)

* Documentation: [django-calaccess-raw-data.californiacivicdata.org](http://django-calaccess-raw-data.californiacivicdata.org)
* Issues: [github.com/california-civic-data-coalition/django-calaccess-raw-data/issues](https://github.com/california-civic-data-coalition/django-calaccess-raw-data/issues)
* Packaging: [pypi.python.org/pypi/django-calaccess-raw-data](https://pypi.python.org/pypi/django-calaccess-raw-data)
* Testing: [travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data](https://travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data)
* Coverage: [coveralls.io/r/california-civic-data-coalition/django-calaccess-raw-data](https://coveralls.io/r/california-civic-data-coalition/django-calaccess-raw-data)
